@@ -7,4 +7,7 @@ class Discoverable(SSDPDiscoverable):
 
     def get_entries(self):
         """Get all the LionBox uPnP entries."""
-        return self.find_by_st("urn:schemas-upnp-org:service:ConnectionManager:1")
+        return self.find_by_device_description({
+            "manufacturer": "Justin Maggard",
+            "deviceType": "urn:schemas-upnp-org:device:MediaServer:1"
+        })
